// Copyright (c) 2018 Dominic Masters
//
// MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import React from 'react';
import { NavLink } from 'react-router-dom';

import { withLanguage } from '@public/language/Language';
import BannerImageSection from '@sections/image/banner/BannerImageSection';
import { PageBoundary } from '@components/page/Page';

import Image from '@objects/image/Image';
import Button from '@objects/input/button/Button';
import ContentBox from '@objects/content/box/ContentBox';
import { Title, Paragraph } from '@objects/typography/Typography';

import Styles from './FeaturedArticleSection.scss';

export default withLanguage(props => {
  let { article, lang } = props;

  return (
    <BannerImageSection
      className="c-featured-article"
      src={ article.image } alt={ article.title } loadable
    >
      <PageBoundary className="c-featured-article__content" full>

        <ContentBox box className="c-featured-article__header">
          <Title className="c-featured-article__title">
            <NavLink to={ article.url } children={ article.title} />
          </Title>
        </ContentBox>

        <ContentBox box className="c-featured-article__body">
          <Paragraph className="c-featured-article__description">
            { article.shortDescription }&nbsp;
            <NavLink to={ article.url } children={ lang.blog.article.readMore } />
          </Paragraph>
        </ContentBox>

      </PageBoundary>
    </BannerImageSection>
  );
});
